@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from pathlib import Path
+from os import PathLike
 
 from blx.cid import CID
 from blx.progress import Progress
@@ -9,7 +9,7 @@ from blx.service_exit import ServiceExit
 __all__ = ["digest"]
 
 
-def digest(file: Path, show_progress=True):
+def digest(file: str | PathLike[str], show_progress=True):
     with Progress("Digest", disable=not show_progress) as progress:
         try:
             return CID.from_file(file, progress)
